@@ -8,11 +8,14 @@ import core_main_app.components.xsl_transformation.api as xsl_api
 class XsltSelectionForm(forms.Form):
     """ Xslt selection form
     """
-    xslt_list = forms.MultipleChoiceField(label='', widget=forms.SelectMultiple(), required=False)
+
+    xslt_list = forms.MultipleChoiceField(
+        label="", widget=forms.SelectMultiple(), required=False
+    )
 
     def __init__(self, *args, **kwargs):
         super(XsltSelectionForm, self).__init__(*args, **kwargs)
-        self.fields['xslt_list'].choices = _get_xsl()
+        self.fields["xslt_list"].choices = _get_xsl()
 
 
 def _get_xsl():
